References
==========
.. automodule:: pykeen.models.unimodal
.. automodule:: pykeen.models.multimodal

.. [ali2020a] Ali, M., *et al.* (2020). `Bringing Light Into the Dark: A Large-scale Evaluation of Knowledge
   Graph Embedding Models Under a Unified Framework <http://arxiv.org/abs/2006.13365>`_. *arXiv*, 2006.13365.

.. [safavi2020] Safavi, T. & Koutra, D. (2020). `CoDEx: A Comprehensive Knowledge Graph
   Completion Benchmark <http://arxiv.org/abs/2009.07810>`_.  *arXiv*, 2009.07810.
